==> comedi-0.5.0.tgz: comedi-0.5.0/demo/job.c <==
#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

#define N_SAM 10000

void help(void)
{
	fprintf(stderr,"chart <channel number> [output file]\n");
	exit(0);
}

comedi_sample s[N_SAM];

char line[]="================================================================================";
void main(int argc,char *argv[])
{
	int i=0,chan;
	int r,in;
	int outf=0;
	FILE *out;
	comedi_trig it;
	int flags,val;
	int bytes;
	double freq;
	
	if(argc<2 || argc>3)help();

	if(!sscanf(argv[1],"%d",&chan))help();

	in=open("/dev/comedi0",O_RDWR);
	if(!in){
		fprintf(stderr,"cannot open /dev/comedi1\n");
		exit(0);
	}

	comedi_getparam(in,chan,COMEDI_IO,&flags,&val);
	/*if(!(val&COMEDI_IO_INPUT)){
		fprintf(stderr,"not input channel\n");
		exit(0);
	}*/
	
	if(argc>2){
		outf=1;
		out=fopen(argv[2],"w");
		if(!out){
			fprintf(stderr,"cannot open %s\n",argv[2]);
			exit(1);
		}
	}

	it.chan=chan;
	it.io=COMEDI_IO_INPUT;
	it.n=N_SAM;
	it.trigsrc=COMEDI_TRIGCLK;

	freq=10000;
	r=comedi_get_timer(in,chan,&freq,&it.trigvar);
printf("%d %g %d 0x%x\n",r,freq,it.trigvar,it.trigvar);

	r=ioctl(in,COMEDI_TRIG,&it);
	if(r<0){
		perror("ioctl: ");
		exit(0);
	}

	bytes=read(in,s,N_SAM*sizeof(comedi_sample));
	if(bytes<0){
		perror("read: ");
		exit(0);
	}
	printf("%d\n",bytes);
/*
	for(i=0;i<N_SAM;i++){
		printf("%d %d\n",i,s[i].data);
	}
*/
	for(i=0;i<10;i++){
		printf("%d %d\n",i,s[i].data);
	}
	for(i=N_SAM-10;i<N_SAM;i++){
		printf("%d %d\n",i,s[i].data);
	}
}

==> comedi-0.5.1.tgz: comedi-0.5.1/demo/job.c <==
#include <stdio.h>
#include <comedilib.h>
#include <fcntl.h>
#include <unistd.h>
#include <sys/ioctl.h>
#include <errno.h>

#define N_SAM 10000

void help(void)
{
	fprintf(stderr,"chart <channel number> [output file]\n");
	exit(0);
}

comedi_sample s[N_SAM];

char line[]="================================================================================";

int main(int argc,char *argv[])
{
	int i=0,chan;
	int r,in;
	int outf=0;
	FILE *out;
	comedi_trig it;
	int flags,val;
	int bytes;
	double freq;
	
	if(argc<2 || argc>3)help();

	if(!sscanf(argv[1],"%d",&chan))help();

#define FN "/dev/comedi0"
	in=open(FN,O_RDWR);
	if(in<0){
		perror(FN);
		exit(0);
	}

	comedi_getparam(in,chan,COMEDI_IO,&flags,&val);
	/*if(!(val&COMEDI_IO_INPUT)){
		fprintf(stderr,"not input channel\n");
		exit(0);
	}*/
	
	if(argc>2){
		outf=1;
		out=fopen(argv[2],"w");
		if(!out){
			fprintf(stderr,"cannot open %s\n",argv[2]);
			exit(1);
		}
	}

	it.chan=chan;
	it.io=COMEDI_IO_INPUT;
	it.n=N_SAM;
	it.trigsrc=COMEDI_TRIGCLK;

	freq=10000;
	r=comedi_get_timer(in,chan,&freq,&it.trigvar);
printf("%d %g %d 0x%x\n",r,freq,it.trigvar,it.trigvar);

	r=ioctl(in,COMEDI_TRIG,&it);
	if(r<0){
		perror("ioctl: ");
		exit(0);
	}

	bytes=read(in,s,N_SAM*sizeof(comedi_sample));
	if(bytes<0){
		perror("read: ");
		exit(0);
	}
	printf("%d\n",bytes);
/*
	for(i=0;i<N_SAM;i++){
		printf("%d %d\n",i,s[i].data);
	}
*/
	for(i=0;i<10;i++){
		printf("%d %d\n",i,s[i].data);
	}
	for(i=N_SAM-10;i<N_SAM;i++){
		printf("%d %d\n",i,s[i].data);
	}
	
	return 0;
}
